# KaiRoS

### A simple, easy to use terminal weather app.

![image](./.hidden/image.png)

**dependencies**

 ![img](https://img.shields.io/badge/license-MIT-green.svg) ![os](https://img.shields.io/badge/platform-linux%20%7C%20osx-blue.svg) ![py](https://img.shields.io/badge/python-%3E=_3.6-red.svg)

**How to use it ?**

_current weather_, _forecast_, and even _a logo in the ascii art style_… what more can you hope for?

![demo](./.hidden/demo.gif)



**Is it useless ?**

~~Well, maybe.~~ Of course it’s not useless. In fact, it’s quite useful. With it you’ll be able to check the weather forecast! Isn’t it exciting?



**Why would I want it ?**

Well, sometimes you just want to see the weather without the hazard of opening a new browser or moving your hand away from the keyboard. That’s where `KaiRoS` comes in.



**What about the used and “proven” `wttr.in` ?**

![fail1](./.hidden/failure1.gif) ![fail2](./.hidden/failure2.gif)

Pretty self. explanatory. `wttr.in` is not as efficient and/or reliable as `kairos`, also, you need `curl` for it to work… 



**How do I get it ?**

It is uploaded to **PyPI**, so everyone can download it with 

```bash
$ python3 -m pip install wkairos --user
```
##### Note: installed with `wkairos`, but run with `kairos`

###### the name `kairos` is already taken 😭😭
###### by “everyone” I mean everyone with Linux/OSX installed.



**What does `kairos` mean ?**

It means _weather_ in Greek. It’s the name only because it sounds nice (I basically looked that up using [google translate](https://translate.google.com))
